@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package DBIx::Squirrel;
-$DBIx::Squirrel::VERSION = '1.3.5';
+$DBIx::Squirrel::VERSION = '1.3.6';
 =pod
 
 =encoding UTF-8
@@ -14,7 +14,7 @@ DBIx::Squirrel - A C<DBI> extension
 
 =head1 VERSION
 
-version 1.3.5
+version 1.3.6
 
 =cut
 
@@ -49,7 +49,7 @@ BEGIN {
     *DBIx::Squirrel::NORMALIZE_SQL                = *DBIx::Squirrel::util::NORMALISE_SQL;
 
     unless (defined $DBIx::Squirrel::VERSION) {
-        my $v = "1.3.5";
+        my $v = "1.3.6";
         *DBIx::Squirrel::VERSION = \$v;
     }
 }
@@ -1342,26 +1342,6 @@ be returned if the statement executed successfully, otherwise C<undef> is
 returned.
 
 
-=head4 C<execute>
-
-    $rv_or_undef = $itor->execute
-    $rv_or_undef = $itor->execute(@bind_values)
-    $rv_or_undef = $itor->execute(@transforms)
-    $rv_or_undef = $itor->execute(@bind_values, @transforms)
-    $rv_or_undef = $itor->execute(%bind_mappings)
-    $rv_or_undef = $itor->execute(%bind_mappings, @transforms)
-    $rv_or_undef = $itor->execute(\@bind_values)
-    $rv_or_undef = $itor->execute([@bind_values, @transforms])
-    $rv_or_undef = $itor->execute(\%bind_mappings)
-    $rv_or_undef = $itor->execute(\%bind_mappings, @transforms)
-
-Executes the iterator's underlying statement, as well as resetting the
-iterator's internal state.
-
-When called with no arguments, any bind-values and transformations passed to
-the iterator at the time of construction will be honoured.
-
-
 =head4 C<first>
 
     $result = $itor->first;
@@ -1566,6 +1546,26 @@ The following package globals define the relevant default settings:
     $DBIx::Squirrel::it::BUFFER_SIZE_LIMIT   = 64;  # maximum buffer-size
 
 
+=head4 C<start>
+
+    $rv_or_undef = $itor->start
+    $rv_or_undef = $itor->start(@bind_values)
+    $rv_or_undef = $itor->start(@transforms)
+    $rv_or_undef = $itor->start(@bind_values, @transforms)
+    $rv_or_undef = $itor->start(%bind_mappings)
+    $rv_or_undef = $itor->start(%bind_mappings, @transforms)
+    $rv_or_undef = $itor->start(\@bind_values)
+    $rv_or_undef = $itor->start([@bind_values, @transforms])
+    $rv_or_undef = $itor->start(\%bind_mappings)
+    $rv_or_undef = $itor->start(\%bind_mappings, @transforms)
+
+Culminates in the iterator's underlying statement being executed, after
+resetting the iterator's internal state.
+
+When called with no arguments, any bind-values and transformations passed to
+the iterator at the time of construction are used.
+
+
 =head4 C<sth>
 
     $sth = $itor->sth;
