@@ -7,10 +7,11 @@ package    # hide from PAUSE
 BEGIN {
     require DBIx::Squirrel
       unless defined($DBIx::Squirrel::VERSION);
+    require Exporter;
     $DBIx::Squirrel::Transform::IO::VERSION   = $DBIx::Squirrel::VERSION;
     @DBIx::Squirrel::Transform::IO::ISA       = qw/Exporter/;
-    @DBIx::Squirrel::Transform::IO::EXPORT    = qw/stdout stderr/;
     @DBIx::Squirrel::Transform::IO::EXPORT_OK = qw/stdout stderr/;
+    @DBIx::Squirrel::Transform::IO::EXPORT    = @DBIx::Squirrel::Transform::IO::EXPORT_OK;
 }
 
 use DBIx::Squirrel::util qw/result/;
@@ -19,7 +20,7 @@ sub stdout {
     if (@_) {
         my $format = shift;
         return sub {
-            printf STDOUT $format, result;
+            printf STDOUT $format, @_;
             return result;
         }
     }
@@ -35,7 +36,7 @@ sub stderr {
     if (@_) {
         my $format = shift;
         return sub {
-            printf STDERR $format, result;
+            printf STDERR $format, @_;
             return result;
         }
     }
